@@ -60,7 +60,7 @@ class ApplicationManager(object):
     application_factory = Application
 
     default_log = os.path.join(get_variable("CHECKBOX_DATA", "."), "checkbox.log")
-    default_log_level = "debug"
+    default_log_level = "info"
 
     def parse_options(self, args):
         usage = _("Usage: checkbox [OPTIONS]")
@@ -81,13 +81,13 @@ class ApplicationManager(object):
                           default=[],
                           help=_("Configuration override parameters."))
         parser.add_option("-b", "--blacklist",
-                          help=_("Shorthand for --config=checkbox/plugins/jobs_info/blacklist."))
+                          help=_("Shorthand for --config=.*/jobs_info/blacklist."))
         parser.add_option("-B", "--blacklist-file",
-                          help=_("Shorthand for --config=checkbox/plugins/jobs_info/blacklist_file."))
+                          help=_("Shorthand for --config=.*/jobs_info/blacklist_file."))
         parser.add_option("-w", "--whitelist",
-                          help=_("Shorthand for --config=checkbox/plugins/jobs_info/whitelist."))
+                          help=_("Shorthand for --config=.*/jobs_info/whitelist."))
         parser.add_option("-W", "--whitelist-file",
-                          help=_("Shorthand for --config=checkbox/plugins/jobs_info/whitelist_file."))
+                          help=_("Shorthand for --config=.*/jobs_info/whitelist_file."))
         return parser.parse_args(args)
 
     def create_application(self, args=sys.argv):
@@ -102,7 +102,7 @@ class ApplicationManager(object):
 
         # Replace shorthands
         for shorthand in "blacklist", "blacklist_file", "whitelist", "whitelist_file":
-            key = "checkbox/plugins/jobs_info/%s" % shorthand
+            key = ".*/jobs_info/%s" % shorthand
             value = getattr(options, shorthand)
             if value:
                 options.config.append("=".join([key, value]))
