@@ -20,6 +20,8 @@ import copy
 
 from checkbox.contrib.persist import Persist, MemoryBackend
 
+from checkbox.job import UNINITIATED
+
 from checkbox.lib.resolver import Resolver
 
 from checkbox.plugin import Plugin
@@ -42,6 +44,7 @@ class SuitesPrompt(Plugin):
 
         self._depends = {}
         self._jobs = {}
+        self._statuses = {}
         self._persist = None
         self._recover = False 
 
@@ -79,6 +82,8 @@ class SuitesPrompt(Plugin):
             self._jobs[job["name"]] = job[attribute]
             if "suite" in job:
                 self._depends[job["name"]] = [job["suite"]]
+            if job.get("type") == "test":
+                self._statuses[job["name"]] = job["status"]
 
     def prompt_gather(self, interface):
         # Resolve dependencies
@@ -93,31 +98,28 @@ class SuitesPrompt(Plugin):
             suboptions = options
             dependencies = resolver.get_dependencies(job)
             for dependency in dependencies:
-                suboptions = suboptions.setdefault(self._jobs[dependency], {})
+                value = self._statuses.get(dependency, {})
+                suboptions = suboptions.setdefault(self._jobs[dependency], value)
 
         # Build defaults
         defaults = self.persist.get("default")
         if defaults is None:
             defaults = copy.deepcopy(options)
 
-        # Only prompt if not recovering
-        if interface.direction == PREV or not self._recover:
-            self._recover = False
-
-            # Get results
-            defaults = interface.show_tree(_("Select the suites to test"),
-                options, defaults)
-            self.persist.set("default", defaults)
+        # Get results
+        defaults = interface.show_tree(_("Select the suites to test"),
+            options, defaults)
+        self.persist.set("default", defaults)
 
         # Get tests to ignore
         def get_ignore_jobs(options, results):
             jobs = []
-            for k, v in options.iteritems():
-                if not v and k not in results:
-                    jobs.append(k)
-
-                else:
-                    jobs.extend(get_ignore_jobs(options[k], results.get(k, {})))
+            if isinstance(options,dict):
+                for k, v in options.iteritems():
+                    if v == UNINITIATED and k not in results:
+                        jobs.append(k)
+                    else:
+                        jobs.extend(get_ignore_jobs(options[k], results.get(k, {})))
 
             return jobs
 
